/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef CONFIGDIALOG_H
#define CONFIGDIALOG_H

#include "common.h"
#include "ui_configdialog.h"

#include <QFontDialog>
#include <QMap>
#include <fly-ocr/fly-ocr.h>

class ConfigDialog : public QDialog
{
    Q_OBJECT
public:
    ConfigDialog(QWidget* parent = nullptr);

    QStringList searchLangCultures(const QString& code) const;

    bool useUtf8() const;

    static void openSpellingDir();

public slots:
    void disableDictInstall();
    void disableUpdateCheck();
    void accept() override;

private:
    enum Location {SystemLocation = 0, UserLocation = 1};
    static const QMap<QString, QString> LANG_LOOKUP;
    static const QMultiMap<QString, QString> LANGUAGE_CULTURES;

    Ui::ConfigDialog ui;
    QFontDialog m_fontDialog;

    static QString spellingLocation(Location location);
};

#endif // CONFIGDIALOG_H
