/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef DJVUDOCUMENT_H
#define DJVUDOCUMENT_H

#include <QImage>
#include <QVector>

typedef struct ddjvu_context_s    ddjvu_context_t;
typedef struct ddjvu_document_s   ddjvu_document_t;
typedef struct ddjvu_format_s     ddjvu_format_t;

class DjVuDocument
{
public:
    DjVuDocument();
    ~DjVuDocument();

    struct Page {
        int width;
        int height;
        int dpi;
    };

    bool openFile( const QString& fileName );
    void closeFile();
    QImage image(int pageno, int resolution);
    int pageCount() const
    {
        return m_pages.size();
    }
    const Page& page(int pageno) const { return m_pages[pageno]; }

private:

    ddjvu_context_t* m_djvu_cxt = nullptr;
    ddjvu_document_t* m_djvu_document = nullptr;
    ddjvu_format_t* m_format = nullptr;
    QVector<Page> m_pages;
};

#endif
