/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef HOCRODTEXPORTER_H
#define HOCRODTEXPORTER_H

#include "common.h"
#include "hocrexporter.h"

#include <QObject>
#include <QString>

class HOCRItem;
class QImage;
class QRect;
class QuaZip;
class QXmlStreamWriter;


class HOCROdtExporter : public HOCRExporter
{
    Q_OBJECT
public:
    bool run(const HOCRDocument* hocrdocument, const QString& outname, const ExporterSettings* settings = nullptr) override;

private:
    void writeImage(QuaZip& zip, QMap<const HOCRItem*, QString>& images, const HOCRItem* item);
    void writeFontFaceDecls(QSet<QString>& families, const HOCRItem* item, QXmlStreamWriter& writer);
    void writeFontStyles(QMap<QString, QMap<double, QString> >& styles, const HOCRItem* item, QXmlStreamWriter& writer, int& counter);
    void printItem(QXmlStreamWriter& writer, const HOCRItem* item, int pageNr, int dpi, const QMap<QString, QMap<double, QString> >& fontStyleNames, const QMap<const HOCRItem*, QString>& images);

private slots:
    bool setSource(const QString& sourceFile, int page, int dpi, double angle);
    QImage getSelection(const QRect& bbox);
};

#endif // HOCRODTEXPORTER_H
