/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef HOCRPDFEXPORTWIDGET_H
#define HOCRPDFEXPORTWIDGET_H

#include <QImage>
#include <QVector>

#include "hocrpdfexporter.h"
#include "ui_pdfexportwidget.h"

class QGraphicsPixmapItem;

class DisplayerToolHOCR;
class HOCRDocument;
class HOCRPage;


class HOCRPdfExportWidget : public QWidget
{
    Q_OBJECT
public:
    HOCRPdfExportWidget(DisplayerToolHOCR* displayerTool, const HOCRDocument* hocrdocument = nullptr, const HOCRPage* hocrpage = nullptr, QWidget* parent = nullptr);
    ~HOCRPdfExportWidget();
    void setPreviewPage(const HOCRDocument* hocrdocument, const HOCRPage* hocrpage);
    HOCRPdfExporter::PDFSettings getPdfSettings() const;

signals:
    void validChanged(bool valid);

private:
    Ui::PdfExportWidget ui;
    QGraphicsPixmapItem* m_preview = nullptr;
    DisplayerToolHOCR* m_displayerTool;
    const HOCRDocument* m_document = nullptr;
    const HOCRPage* m_previewPage;


private slots:
    void backendChanged();
    void toggleBackendHint();
    void importMetadataFromSource();
    void imageFormatChanged();
    void imageCompressionChanged();
    void paperSizeChanged();
    void updatePreview();
    void updateValid();
};

#endif // HOCRPDFEXPORTWIDGET_H
