/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef HOCRPROOFREADWIDGET_H
#define HOCRPROOFREADWIDGET_H

#include <QMap>
#include <QFrame>

class QLabel;
class QSpinBox;
class QTreeView;
class QVBoxLayout;
class HOCRItem;

class HOCRProofReadWidget : public QFrame
{
    Q_OBJECT
public:
    HOCRProofReadWidget(QTreeView* treeView, QWidget* parent = nullptr);
    void clear();
    QTreeView* documentTree() const { return m_treeView; }
    void setConfidenceLabel(int wconf);
    QString confidenceStyle(int wconf) const;
    void adjustFontSize(int diff);

private:
    class LineEdit;

    QTreeView* m_treeView = nullptr;
    QVBoxLayout* m_linesLayout = nullptr;
    const HOCRItem* m_currentLine = nullptr;
    QWidget* m_controlsWidget = nullptr;
    QLabel* m_confidenceLabel = nullptr;
    QMap<const HOCRItem*, QWidget*> m_currentLines;
    QSpinBox* m_spinLinesBefore = nullptr;
    QSpinBox* m_spinLinesAfter = nullptr;
    int m_fontSizeDiff = 0;

    // Disable auto tab handling
    bool focusNextPrevChild(bool) override { return false; }

    void repositionWidget();

private slots:
    void updateWidget(bool force = false);
    void showShortcutsDialog();
};


#endif // HOCRPROOFREADWIDGET_H
