/***
   This file is part of fly-ocr.

   Copyright (C) 2016-2020 Sandro Mani <manisandro@gmail.com>
   Copyright (C) 2021 LLC "RusBITech-Astra" (https://astralinux.ru)

    Based on gImageReader source code by Sandro Mani under the GNU
    General Public License (GPL) version 3 or later

   Foobar is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   Foobar is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with fly-ocr. If not, see <https://www.gnu.org/licenses/>.
***/

#ifndef RECOGNITIONMENU_H
#define RECOGNITIONMENU_H

#include <QMenu>
#include "configdialog.h"
#include "ui_characterlistdialog.h"

class QActionGroup;

class RecognitionMenu : public QMenu
{
    Q_OBJECT
public:
    RecognitionMenu(QWidget* parent = nullptr);

    void rebuild();
    int getPageSegmentationMode() const;
    QString getCharacterWhitelist() const;
    QString getCharacterBlacklist() const;
    const QList<FlyOcr::Lang>& selectedLanguages() const;
    QString selectedLanguageCode() const;

public slots:
    void selectLanguages();

signals:
    void selectedLanguagesChanged(const QList<FlyOcr::Lang>& langs);

private slots:
    void onPsmSelected(QAction* action);

private:
    QStringList serialize(const QList<FlyOcr::Lang>& langs) const;

    //QMenu* m_menuMultilanguage = nullptr;
    //QActionGroup* m_langMenuRadioGroup = nullptr;
    //QActionGroup* m_langMenuCheckGroup = nullptr;
    QList<FlyOcr::Lang> m_selectedLanguages;
    QActionGroup* m_psmCheckGroup = nullptr;
    QDialog* m_charListDialog = nullptr;
    Ui::CharacterListDialog m_charListDialogUi;
    QString m_engineName;
};

#endif // RECOGNITIONMENU_H
